diff --git a/wp-includes/user.php b/wp-includes/user.php
index a1e88f2e5a..e0645493a2 100644
--- a/wp-includes/user.php
+++ b/wp-includes/user.php
@@ -2574,7 +2574,7 @@ function register_new_user( $user_login, $user_email ) {
 			'registerfail',
 			sprintf(
 				/* translators: %s: Admin email address. */
-				__( '<strong>Error</strong>: Couldn&#8217;t register you&hellip; please contact the <a href="mailto:%s">webmaster</a> !' ),
+				__( '<strong>Error</strong>: Couldn&#8217;t register you&hellip; please contact the <a href="mailto:%s">site admin</a>!' ),
 				get_option( 'admin_email' )
 			)
 		);
diff --git a/wp-includes/version.php b/wp-includes/version.php
index 9bb02884ea..2fdeb294b9 100644
--- a/wp-includes/version.php
+++ b/wp-includes/version.php
@@ -13,7 +13,7 @@
  *
  * @global string $wp_version
  */
-$wp_version = '5.5-alpha-48048';
+$wp_version = '5.5-alpha-48049';
 
 /**
  * Holds the WordPress DB revision, increments when changes are made to the WordPress DB schema.
diff --git a/wp-admin/ms-delete-site.php b/wp-admin/ms-delete-site.php
index 817ff93560..baad601a11 100644
--- a/wp-admin/ms-delete-site.php
+++ b/wp-admin/ms-delete-site.php
@@ -52,7 +52,7 @@ if ( isset( $_POST['action'] ) && 'deleteblog' === $_POST['action'] && isset( $_
 
 	$switched_locale = switch_to_locale( get_locale() );
 
 	/* translators: Do not translate USERNAME, URL_DELETE, SITE_NAME: those are placeholders. */
 	$content = __(
 		"Howdy ###USERNAME###,
 
@@ -68,8 +68,8 @@ some time in the future! (But remember your current site and username
 are gone forever.)
 
 Thanks for using the site,
-Webmaster
-###SITE_NAME###"
+All at ###SITENAME###
+###SITEURL###"
 	);
 	/**
 	 * Filters the email content sent when a site in a Multisite network is deleted.
@@ -82,7 +82,8 @@ Webmaster
 
 	$content = str_replace( '###USERNAME###', $user->user_login, $content );
 	$content = str_replace( '###URL_DELETE###', $url_delete, $content );
-	$content = str_replace( '###SITE_NAME###', get_network()->site_name, $content );
+	$content = str_replace( '###SITENAME###', get_network()->site_name, $content );
+	$content = str_replace( '###SITEURL###', network_home_url(), $content );
 
 	wp_mail(
 		get_option( 'admin_email' ),
@@ -52,7 +52,7 @@ if ( isset( $_POST['action'] ) && 'deleteblog' === $_POST['action'] && isset( $_
 	$switched_locale = switch_to_locale( get_locale() );
 
-	/* translators: Do not translate USERNAME, URL_DELETE, SITE_NAME: those are placeholders. */
+	/* translators: Do not translate USERNAME, URL_DELETE, SITENAME, SITEURL: those are placeholders. */
 	$content = __(
 		"Howdy ###USERNAME###,